import matplotlib.pyplot as plt
from numpy import loadtxt

import matplotlib
matplotlib.rcParams.update({'errorbar.capsize':1})
del matplotlib

period = 3.3354773
epoch = 2457297.75771  #vsx

def get_phased_lc(filename):
	file = loadtxt(filename)
	tjd = file[:,0]
	mag = file[:,1]
	err = file[:,2]
	cor = 0
	if tjd[0] < 50000:
		tjd = tjd + 2450000

	data = {}
	for i in range(len(tjd)):
		data[(tjd[i] - epoch) / period % 1] = mag[i], err[i]
	phase = sorted(data.keys())
	magg, errr = [], []
	for i in phase:
		magg.append(data[i][0])
		errr.append(data[i][1])

	P, M, E = [], [], []
	for n in [[len(phase) // 2, len(phase), -1], [0, len(phase), 0], [0, len(phase) // 2, 1]]:
		for i in range(n[0], n[1]):
			P.append(phase[i] + n[2])
			M.append(magg[i])
			E.append(errr[i])

	tjd = tjd - 2450000

	return tjd, mag, err, P, M, E

tjd_1, mag_1, err_1, P_1, M_1, E_1 = get_phased_lc("ASAS-SN_HJD.dat")
tjd_2, mag_2, err_2, P_2, M_2, E_2 = get_phased_lc("OMC_HJD.dat")
tjd_3, mag_3, err_3, P_3, M_3, E_3 = get_phased_lc("AAVSO_HJD.dat")

marker = 'x'
msize = 5
elinewidth = 0.8

plt.figure(figsize=(7.5,4))
plt.title("Světelná křivka QT Cyg")
plt.errorbar(x=tjd_2, y=mag_2, yerr=err_2, elinewidth=elinewidth, marker=marker, markersize=msize,linewidth=0, label="OMC (10 min)")
plt.errorbar(x=tjd_1, y=mag_1, yerr=err_1, elinewidth=elinewidth, marker=marker,  markersize=msize,linewidth=0, label="ASAS-SN")
plt.errorbar(x=tjd_3, y=mag_3, yerr=err_3, elinewidth=elinewidth, marker=marker,  markersize=msize,linewidth=0, label="AAVSO")
plt.legend()
plt.xlabel("HJD-2450000")
plt.ylabel("V [mag]")
plt.gca().invert_yaxis()
plt.savefig("holý_data.png", dpi=140)
plt.close()

plt.figure(figsize=(7.5,4))
plt.title("Fázová křivka QT Cyg")
plt.errorbar(x=P_2, y=M_2, yerr=E_2, elinewidth=elinewidth, marker=marker,  markersize=msize,linewidth=0, label="OMC (10 min)")
plt.errorbar(x=P_1, y=M_1, yerr=E_1, elinewidth=elinewidth, marker=marker,  markersize=msize,linewidth=0, label="ASAS-SN")
plt.errorbar(x=P_3, y=M_3, yerr=E_3, elinewidth=elinewidth, marker=marker,  markersize=msize,linewidth=0, label="AAVSO")
plt.legend()
plt.xlabel("Fáze")
plt.ylabel("V [mag]")
plt.xlim([-0.55, 1.55])
plt.gca().invert_yaxis()
plt.savefig("zfázováno.png", dpi=140)
