import matplotlib.pyplot as plt
from matplotlib import gridspec
from numpy import loadtxt, linspace, log10, log
from astropy.constants.iau2015 import L_sun

# loadfile
file = loadtxt("evo_track.txt", unpack=True)
init_M, Z, age, log_L, log_T = file[0,:], file[1,:],file[4,:], file[6,:], file[7,:]

# sort by mass
mnozina = sorted(list(set(init_M)))
seznam = [[[], [], []] for i in range(len(mnozina))]
for a, z, m, l, t in zip(age, Z, init_M, log_L, log_T):
	if z == 0.02:
		seznam[mnozina.index(m)][0].append(l)
		seznam[mnozina.index(m)][1].append(t)
		seznam[mnozina.index(m)][2].append(a)

# initial values
m_V = 6.46
par = 2.2801e-3
M = 5 * log10(par) + 5 + m_V
L = 10**(-0.4 * M)
T = 22500
log_g = 3.95

# mass determination
fig = plt.figure(figsize=(7.7, 6))
for i in range(0, len(mnozina)):
	label = str(mnozina[i])
	if int(mnozina[i]) >= 10:
		label = label[:-2]
	plt.plot(seznam[i][1], seznam[i][0], label=label + " M$_\odot$")
	plt.plot(log10(T), log_g, 'o', color="C0")
plt.gca().invert_xaxis()
plt.legend(ncol=2)
plt.xticks(linspace(3.5, 5, 16))
plt.yticks(linspace(-1, 7, 17))
plt.xlabel("log $T$", size=13)
plt.ylabel("log $L\,/\,L_\odot$", size=13)
plt.savefig("mass.png", dpi=250)

plt.close()

# age determination
plt.figure(figsize=(7.7, 6))
plt.plot(seznam[-9][1], seznam[-9][0], 'o-',c ="C2", label="9 M$_\odot$")
plt.plot(seznam[-8][1], seznam[-8][0], 'o-',c ="C3", label="12 M$_\odot$")
plt.plot(log10(T), log_g, 'o', color="C0")
plt.xlabel("log $T$", size=13)
plt.ylabel("log $L\,/\,L_\odot$", size=13)
plt.xticks(linspace(3.4, 4.5, 12))
plt.yticks(linspace(3.5, 4.9, 15))
plt.gca().invert_xaxis()
plt.legend(loc=2)

for i in range(0, 9):
	plt.text(seznam[-8][1][i] - 0.005, seznam[-8][0][i] - 0.05, "{} Gyr".format(int(round(seznam[-8][2][i] / 1e6))))
	plt.text(seznam[-9][1][i] - 0.005, seznam[-9][0][i] - 0.05, "{} Gyr".format(int(round(seznam[-9][2][i] / 1e6))))
for i in range(13, 19):
	plt.text(seznam[-8][1][i] - 0.005, seznam[-8][0][i] - 0.05, "{} Gyr".format(int(round(seznam[-8][2][i] / 1e6))))
	plt.text(seznam[-9][1][i] - 0.005, seznam[-9][0][i] - 0.05, "{} Gyr".format(int(round(seznam[-9][2][i] / 1e6))))
for i in range(19, len(seznam[-9][0]), 6):
	plt.text(seznam[-9][1][i] - 0.005, seznam[-9][0][i] - 0.05, "{} Gyr".format(int(round(seznam[-9][2][i] / 1e6))))
for i in range(19, len(seznam[-8][0]), 6):
	plt.text(seznam[-8][1][i] - 0.005, seznam[-8][0][i] - 0.05, "{} Gyr".format(int(round(seznam[-8][2][i] / 1e6))))

plt.savefig("age.png", dpi=250)
